@@ -10,16 +10,23 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import json
 import random
-import string
+import six
 import subprocess
 
 from oslotest import base
+import simplejson as json
 
 
 RP_PREFIX = 'osc-placement-functional-tests-'
 
+# argparse in python 2 and 3 have different error messages
+ARGUMENTS_MISSING = 'too few arguments'
+ARGUMENTS_REQUIRED = 'argument %s is required'
+if six.PY3:
+    ARGUMENTS_MISSING = 'the following arguments are required'
+    ARGUMENTS_REQUIRED = 'the following arguments are required: %s'
+
 
 class BaseTestCase(base.BaseTestCase):
     VERSION = None
@@ -47,6 +54,25 @@ class BaseTestCase(base.BaseTestCase):
         else:
             return result
 
+    def rand_name(self, name='', prefix=None):
+        """Generate a random name that includes a random number
+
+        :param str name: The name that you want to include
+        :param str prefix: The prefix that you want to include
+        :return: a random name. The format is
+                 '<prefix>-<name>-<random number>'.
+                 (e.g. 'prefixfoo-namebar-154876201')
+        :rtype: string
+        """
+        # NOTE(lajos katona): This method originally is in tempest-lib.
+        randbits = str(random.randint(1, 0x7fffffff))
+        rand_name = randbits
+        if name:
+            rand_name = name + '-' + rand_name
+        if prefix:
+            rand_name = prefix + '-' + rand_name
+        return rand_name
+
     def assertCommandFailed(self, message, func, *args, **kwargs):
         signature = [func]
         signature.extend(args)
@@ -56,16 +82,14 @@ class BaseTestCase(base.BaseTestCase):
 
         except subprocess.CalledProcessError as e:
             self.assertIn(
-                message, e.output,
+                message, six.text_type(e.output),
                 'Command "%s" fails with different message' % e.cmd)
 
     def resource_provider_create(self,
                                  name='',
                                  parent_provider_uuid=None):
         if not name:
-            random_part = ''.join(random.choice(string.ascii_letters)
-                                  for i in range(10))
-            name = RP_PREFIX + random_part
+            name = self.rand_name(name='', prefix=RP_PREFIX)
 
         to_exec = 'resource provider create ' + name
         if parent_provider_uuid is not None:
@@ -99,7 +123,7 @@ class BaseTestCase(base.BaseTestCase):
 
     def resource_provider_list(self, uuid=None, name=None,
                                aggregate_uuids=None, resources=None,
-                               in_tree=None):
+                               in_tree=None, required=None):
         to_exec = 'resource provider list'
         if uuid:
             to_exec += ' --uuid ' + uuid
@@ -112,6 +136,8 @@ class BaseTestCase(base.BaseTestCase):
             to_exec += ' ' + ' '.join('--resource %s' % r for r in resources)
         if in_tree:
             to_exec += ' --in-tree ' + in_tree
+        if required:
+            to_exec += ' ' + ' '.join('--required %s' % t for t in required)
 
         return self.openstack(to_exec, use_json=True)
 
